@@ -83,9 +83,9 @@ QString FilterClawsMail::localMailDirPath()
 
 bool FilterClawsMail::excludeFile(const QString &file)
 {
-    if (file.endsWith(QLatin1String(".claws_cache")) ||
-            file.endsWith(QLatin1String(".claws_mark")) ||
-            file.endsWith(QLatin1String(".mh_sequences"))) {
+    if (file.endsWith(QLatin1String(".claws_cache"))
+        || file.endsWith(QLatin1String(".claws_mark"))
+        || file.endsWith(QLatin1String(".mh_sequences"))) {
         return true;
     }
     return false;
@@ -100,4 +100,3 @@ QString FilterClawsMail::markFile() const
 {
     return QStringLiteral(".claws_mark");
 }
-
